@@ -495,110 +495,181 @@ class ZipArchive implements Countable
     public const ER_CANCELLED = UNKNOWN;
 #endif
 
+    /* since 1.10.0 */
+#ifdef ZIP_ER_DATA_LENGTH
+    /**
+     * N Unexpected length of data
+     * @var int
+     * @cvalue ZIP_ER_DATA_LENGTH
+     */
+    public const ER_DATA_LENGTH = UNKNOWN;
+#endif
+#ifdef ZIP_ER_NOT_ALLOWED
+    /**
+     * Not allowed in torrentzip
+     * @var int
+     * @cvalue ZIP_ER_NOT_ALLOWED
+     */
+    public const ER_NOT_ALLOWED = UNKNOWN;
+#endif
+#ifdef ZIP_AFL_RDONLY
+    /**
+     * read only -- cannot be cleared
+     * @var int
+     * @cvalue ZIP_AFL_RDONLY
+     */
+    public const AFL_RDONLY = UNKNOWN;
+#endif
+#ifdef ZIP_AFL_IS_TORRENTZIP
+    /**
+     * current archive is torrentzipped
+     * @var int
+     * @cvalue ZIP_AFL_IS_TORRENTZIP
+     */
+    public const AFL_IS_TORRENTZIP = UNKNOWN;
+#endif
+#ifdef ZIP_AFL_WANT_TORRENTZIP
+    /**
+     * write archive in torrentzip format
+     * @var int
+     * @cvalue ZIP_AFL_WANT_TORRENTZIP
+     */
+    public const AFL_WANT_TORRENTZIP = UNKNOWN;
+#endif
+#ifdef ZIP_AFL_CREATE_OR_KEEP_FILE_FOR_EMPTY_ARCHIVE
+    /**
+     * don't remove file if archive is empty
+     * @var int
+     * @cvalue ZIP_AFL_CREATE_OR_KEEP_FILE_FOR_EMPTY_ARCHIVE
+     */
+    public const AFL_CREATE_OR_KEEP_FILE_FOR_EMPTY_ARCHIVE = UNKNOWN;
+#endif
+
 #ifdef ZIP_OPSYS_DEFAULT
     /**
      * @var int
      * @cvalue ZIP_OPSYS_DOS
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_DOS = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_AMIGA
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_AMIGA = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_OPENVMS
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_OPENVMS = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_UNIX
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_UNIX = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_VM_CMS
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_VM_CMS = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_ATARI_ST
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_ATARI_ST = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_OS_2
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_OS_2 = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_MACINTOSH
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_MACINTOSH = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_Z_SYSTEM
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_Z_SYSTEM = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_CPM
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_CPM = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_WINDOWS_NTFS
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_WINDOWS_NTFS = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_MVS
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_MVS = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_VSE
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_VSE = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_ACORN_RISC
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_ACORN_RISC = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_VFAT
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_VFAT = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_ALTERNATE_MVS
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_ALTERNATE_MVS = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_BEOS
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_BEOS = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_TANDEM
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_TANDEM = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_OS_400
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_OS_400 = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_OS_X
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_OS_X = UNKNOWN;
     /**
      * @var int
      * @cvalue ZIP_OPSYS_DEFAULT
+     * @link ziparchive.constants.opsys
      */
     public const OPSYS_DEFAULT = UNKNOWN;
 #endif
@@ -636,6 +707,12 @@ class ZipArchive implements Countable
      */
     public const EM_UNKNOWN = UNKNOWN;
 
+    /**
+     * @var string
+     * @cvalue LIBZIP_VERSION_STR
+     */
+    public const LIBZIP_VERSION = UNKNOWN;
+
     /** @readonly */
     public int $lastId;
     /** @readonly */
@@ -698,6 +775,10 @@ class ZipArchive implements Countable
     /** @tentative-return-type */
     public function getArchiveComment(int $flags = 0): string|false {}
 
+    public function setArchiveFlag(int $flag, int $value): bool {}
+
+    public function getArchiveFlag(int $flag, int $flags = 0): int {}
+
     /** @tentative-return-type */
     public function setCommentIndex(int $index, string $comment): bool {}
 
